.. include:: ../BADGES.rst

Command Line
============

Help::

     tstoolbox –help

about
~~~~~
.. program-output:: tstoolbox about --help
   :prompt:

accumulate
~~~~~~~~~~
.. program-output:: tstoolbox accumulate --help
   :prompt:

add_trend
~~~~~~~~~
.. program-output:: tstoolbox add_trend --help
   :prompt:

aggregate
~~~~~~~~~
.. program-output:: tstoolbox aggregate --help
   :prompt:

calculate_fdc
~~~~~~~~~~~~~
.. program-output:: tstoolbox calculate_fdc --help
   :prompt:

calculate_kde
~~~~~~~~~~~~~
.. program-output:: tstoolbox calculate_kde --help
   :prompt:

clip
~~~~
.. program-output:: tstoolbox clip --help
   :prompt:

convert
~~~~~~~
.. program-output:: tstoolbox convert --help
   :prompt:

convert_index
~~~~~~~~~~~~~~~~~~~~~~~
.. program-output:: tstoolbox convert_index --help
   :prompt:

convert_index_to_julian
~~~~~~~~~~~~~~~~~~~~~~~
.. program-output:: tstoolbox convert_index_to_julian --help
   :prompt:

converttz
~~~~~~~~~
.. program-output:: tstoolbox converttz --help
   :prompt:

correlation
~~~~~~~~~~~
.. program-output:: tstoolbox correlation --help
   :prompt:

createts
~~~~~~~~
.. program-output:: tstoolbox createts --help
   :prompt:

date_offset
~~~~~~~~~~~
.. program-output:: tstoolbox date_offset --help
   :prompt:

date_slice
~~~~~~~~~~
.. program-output:: tstoolbox date_slice --help
   :prompt:

describe
~~~~~~~~
.. program-output:: tstoolbox describe --help
   :prompt:

dtw
~~~
.. program-output:: tstoolbox dtw --help
   :prompt:

equation
~~~~~~~~
.. program-output:: tstoolbox equation --help
   :prompt:

ewm_window
~~~~~~~~~~
.. program-output:: tstoolbox ewm_window --help
   :prompt:

expanding_window
~~~~~~~~~~~~~~~~
.. program-output:: tstoolbox expanding_window --help
   :prompt:

fill
~~~~
.. program-output:: tstoolbox fill --help
   :prompt:

filter
~~~~~~
.. program-output:: tstoolbox filter --help
   :prompt:

fit
~~~
.. program-output:: tstoolbox fit --help
   :prompt:

forecast
~~~~~~~~
.. program-output:: tstoolbox forecast --help
   :prompt:

gof
~~~
.. program-output:: tstoolbox gof --help
   :prompt:

lag
~~~
.. program-output:: tstoolbox lag --help
   :prompt:

normalization
~~~~~~~~~~~~~
.. program-output:: tstoolbox normalization --help
   :prompt:

pca
~~~
.. program-output:: tstoolbox pca --help
   :prompt:

pct_change
~~~~~~~~~~
.. program-output:: tstoolbox pct_change --help
   :prompt:

peak_detection
~~~~~~~~~~~~~~
.. program-output:: tstoolbox peak_detection --help
   :prompt:

pick
~~~~
.. program-output:: tstoolbox pick --help
   :prompt:

plot
~~~~
.. program-output:: tstoolbox plot --help
   :prompt:

rank
~~~~
.. program-output:: tstoolbox rank --help
   :prompt:

read
~~~~
.. program-output:: tstoolbox read --help
   :prompt:

regression
~~~~~~~~~~
.. program-output:: tstoolbox regression --help
   :prompt:

remove_trend
~~~~~~~~~~~~
.. program-output:: tstoolbox remove_trend --help
   :prompt:

replace
~~~~~~~
.. program-output:: tstoolbox replace --help
   :prompt:

rolling_window
~~~~~~~~~~~~~~
.. program-output:: tstoolbox rolling_window --help
   :prompt:

stack
~~~~~
.. program-output:: tstoolbox stack --help
   :prompt:

stdtozrxp
~~~~~~~~~
.. program-output:: tstoolbox stdtozrxp --help
   :prompt:

tstopickle
~~~~~~~~~~
.. program-output:: tstoolbox tstopickle --help
   :prompt:

unstack
~~~~~~~
.. program-output:: tstoolbox unstack --help
   :prompt:
